Media

# Media

## 4 LDs

1. Léon, der Profi (127 min)
   MediaMarkt Bayreuth: 79.99 DEM (01.04.1998)
2. Only Yesterday (98 min)
   San Fransico Laserdiscs: 50.0 USD (18.07.1998)
3. The Dream is Alive (37 min)
   Cinemabilia: 102.9 DEM (29.11.1997)
4. Zwei Welten (105 min)
   MediaMarkt Regensburg: 19.95 DEM (20.09.1997)

## 14 DVDs

1. 12 Monkeys (130 min; RC 1)
   Amazon.com: 23.99 USD (19.03.2000)
2. Cowboy Bebop, Volume 1 (125 min; RC 1)
   Amazon.com: 17.99 USD (07.02.2000)
3. Ein Lied von Liebe und Tod — Gloomy Sunday (108 min; RC 2)
   Amazon.de: 44.99 DEM (27.11.2000)
4. Grave of the Fireflies (88 min; RC 1)
   Planet Anime, Houston: 26.96 USD (30.12.1998)
5. Lola rennt (77 min; RC 2)
   Mediamarkt Bayreuth: 54.99 DEM (09.03.1999)
6. Nach Fünf im Urwald (93 min; RC 2)
   Amazon.de: 39.99 DEM (25.08.2000)
7. Neon Genesis Evangelion - Collection 0:1 (120 min; RC 1)
   Amazon.com: 17.99 USD (07.02.2000)
8. Patlabor 2 - The Movie (100 min; RC 1)
   Amazon.com: 20.96 USD (21.08.2000)
9. Perfect Blue (81 min; RC 1, 2, 4)
   Amazon.com: 20.97 USD (07.02.2000)
10. Princess Mononoke (134 min; RC 1)
    Amazon.com: 23.09 USD (21.08.2000)
11. The Bride with White Hair (92 min; RC 0)
    www.dvdempire.com: 20.45 USD (01.05.1998)
12. The Bride with White Hair 2 (80 min; RC 0)
    www.dvdempire.com: 20.95 USD (28.05.1999)
13. The King of Masks (101 min; RC 1)
    Amazon.com: 23.99 USD (29.08.2000)
14. The Princess Bride (98 min; RC 1)
    Amazon.com: 11.99 USD (06.06.2000)